import React, { useMemo } from 'react'
import { useTranslation } from 'react-i18next'
import { StyleSheet } from 'react-native'

import { User, termsByTitleComparator } from '@holi/core/domain/shared/types'
import { UserChipTypes } from '@holi/core/helpers/useUserChips'
import HoliChip from '@holi/ui/components/molecules/HoliChip'
import HoliChipRow from '@holi/ui/components/molecules/HoliChipRow'
import { HoliTheme, useTheme } from '@holi/ui/styles/theme'

type UserChipRowProps = {
  keyInUserObject: UserChipTypes
  onPressEdit?: () => void
  numberOfLines?: number
  user: User
}

const UserChipRow: React.VoidFunctionComponent<UserChipRowProps> = ({
  onPressEdit,
  numberOfLines,
  user,
  keyInUserObject,
}: UserChipRowProps) => {
  const terms = user ? user[keyInUserObject] || [] : []
  const sortedTerms = [...terms].sort(termsByTitleComparator)
  const { t } = useTranslation()
  const { theme } = useTheme()
  const styles = useMemo(() => getStyles(theme), [theme])

  return (
    <HoliChipRow
      editable={!!onPressEdit}
      title={t(`profile.${keyInUserObject}`)}
      editButtonLabel={t(`profile.${keyInUserObject}.edit`)}
      onPressEdit={onPressEdit}
      testID={`user-profile-${keyInUserObject}`}
    >
      {sortedTerms.length > 0 ? (
        /** FIXME convert to VirtualizedList, FlatList or SectionList */
        sortedTerms.map((term) => (
          <HoliChip
            numberOfLines={numberOfLines}
            key={term.id}
            text={term.title}
            label={term.title}
            disabled
            style={styles.chip}
            fontStyle={styles.chipFont}
          />
        ))
      ) : (
        <HoliChip
          text={''}
          key="edit"
          onPress={onPressEdit}
          label={t(`profile.${keyInUserObject}.add`)}
          style={styles.chip}
          fontStyle={styles.chipFont}
        />
      )}
    </HoliChipRow>
  )
}

const getStyles = (theme: HoliTheme) =>
  StyleSheet.create({
    chip: {
      borderWidth: 1,
      borderColor: theme.colors.foreground30at12Percent,
    },
    chipFont: {
      color: theme.colors.black300,
    },
  })

export default UserChipRow
